@@ -64,11 +64,11 @@
 #include <klocalizedstring.h>
 #include <kconfiggroup.h>
 
-#include <QtCore/QFile>
-#include <QtCore/QHash>
-#include <QtCore/QObject>
-#include <QtCore/QChar>
-#include <QtCore/QCoreApplication>
+#include <QFile>
+#include <QHash>
+#include <QObject>
+#include <QChar>
+#include <QCoreApplication>
 #include <QUrl>
 #include <qstandardpaths.h>
 #include <qlogging.h>
@@ -112,19 +112,19 @@ public:
     {
         open(WriteOnly);
     }
-    bool isSequential() const Q_DECL_OVERRIDE
+    bool isSequential() const override
     {
         return true;
     }
-    qint64 readData(char *, qint64) Q_DECL_OVERRIDE
+    qint64 readData(char *, qint64) override
     {
         return 0; /* eof */
     }
-    qint64 readLineData(char *, qint64) Q_DECL_OVERRIDE
+    qint64 readLineData(char *, qint64) override
     {
         return 0; /* eof */
     }
-    qint64 writeData(const char *, qint64 len) Q_DECL_OVERRIDE
+    qint64 writeData(const char *, qint64 len) override
     {
         return len;
     }
@@ -147,7 +147,7 @@ class KSyslogDebugStream: public KNoDebugStream
 {
     // Q_OBJECT
 public:
-    qint64 writeData(const char *data, qint64 len) Q_DECL_OVERRIDE
+    qint64 writeData(const char *data, qint64 len) override
     {
         if (len) {
             // not using fromRawData because we need a terminating NUL
@@ -164,22 +164,11 @@ private:
     int m_priority;
 };
 
-// can remove this #if clause when depending on Qt 5.4
-#if QT_VERSION < QT_VERSION_CHECK(5, 4, 0)
-extern Q_CORE_EXPORT QString qMessageFormatString(QtMsgType type, const QMessageLogContext & context,
-                                                  const QString & str);
-
-QString qFormatLogMessage(QtMsgType type, const QMessageLogContext & context, const QString & str)
-{
-    return qMessageFormatString(type, context, str);
-}
-#endif
-
 class KFileDebugStream: public KNoDebugStream
 {
     // Q_OBJECT
 public:
-    qint64 writeData(const char *data, qint64 len) Q_DECL_OVERRIDE
+    qint64 writeData(const char *data, qint64 len) override
     {
         if (len) {
             QFile aOutputFile(m_fileName);
@@ -208,7 +197,7 @@ class KMessageBoxDebugStream: public KNoDebugStream
 {
     // Q_OBJECT
 public:
-    qint64 writeData(const char *data, qint64 len) Q_DECL_OVERRIDE
+    qint64 writeData(const char *data, qint64 len) override
     {
         if (len) {
             // Since we are in kdecore here, we cannot use KMsgBox
@@ -229,7 +218,7 @@ class KLineEndStrippingDebugStream: public KNoDebugStream
 {
     // Q_OBJECT
 public:
-    qint64 writeData(const char *data, qint64 len) Q_DECL_OVERRIDE
+    qint64 writeData(const char *data, qint64 len) override
     {
         QByteArray buf = QByteArray::fromRawData(data, len);
         qt_message_output(QtDebugMsg,
@@ -270,7 +259,7 @@ struct KDebugPrivate {
     typedef QHash<unsigned int, Area> Cache;
 
     KDebugPrivate()
-        : config(0), kDebugDBusIface(0), m_disableAll(false)
+        : config(nullptr), kDebugDBusIface(nullptr), m_disableAll(false)
     {
         Q_ASSERT(int(QtDebugMsg) == 0);
         Q_ASSERT(int(QtFatalMsg) == 3);
@@ -575,7 +564,7 @@ struct KDebugPrivate {
     QDebug printHeader(QDebug s)
     {
 #ifdef KDE_EXTENDED_DEBUG_OUTPUT
-        static int printTimeStamp = qgetenv("KDE_DEBUG_TIMESTAMP").toInt();
+        static int printTimeStamp = qEnvironmentVariableIntValue("KDE_DEBUG_TIMESTAMP");
         //s = s.nospace();
         if (printTimeStamp > 0) {
             if (printTimeStamp >= 2) {
@@ -760,7 +749,7 @@ static QString maybeDemangledName(char *name)
             // if we forget about this line and the one that undoes its effect we don't change the
             // internal data of the QByteArray::fromRawData() ;)
             name[mangledNameEnd] = 0;
-            char *demangled = abi::__cxa_demangle(name + mangledNameStart + 1, 0, 0, &status);
+            char *demangled = abi::__cxa_demangle(name + mangledNameStart + 1, nullptr, nullptr, &status);
             name[mangledNameEnd] = '+';
             if (demangled) {
                 QString ret = QString::fromLatin1(name, mangledNameStart + 1) +
@@ -847,7 +836,7 @@ void kClearDebugConfig()
     KDebugPrivate *d = kDebug_data;
     QMutexLocker locker(&d->mutex);
     delete d->config;
-    d->config = 0;
+    d->config = nullptr;
 
     KDebugPrivate::Cache::Iterator it = d->cache.begin(),
                                    end = d->cache.end();
@@ -918,17 +907,17 @@ int KDebug::registerArea(const QByteArray &areaName, bool enabled)
 
 #ifndef KDE_NO_DEBUG_OUTPUT
 
-class KDebug::Block::Private
+class Q_DECL_HIDDEN KDebug::Block::Private
 {
 public:
     QByteArray m_label;
 };
 
 KDebug::Block::Block(const char *label, int area)
-    : m_area(area), d(0)
+    : m_area(area), d(nullptr)
 {
     if (hasNullOutputQtDebugMsg(area)) {
-        d = 0; // remember, for the dtor
+        d = nullptr; // remember, for the dtor
     } else {
         d = new Private;
         d->m_label = label;
